@@ -9,7 +9,7 @@
 #include "lastfm.h"
 #include "lmaster.h"
 #include <QtSql>
-
+#include <QEvent>
 
 class MainWindow : public QMainWindow, private Ui::MainWindow
 {
@@ -83,6 +83,7 @@ public slots:
 void orientationChanged();
 protected:
   void keyPressEvent(QKeyEvent* event);
+  bool eventFilter(QObject *obj, QEvent *event);
 
 };
 
